@@ -1,85 +1,5 @@
 """
-Welcome to Bantam, a framework for running a web server, built on top of *aiohttp*,
-poviding a convience-layer of abstraction.
-The framework allows users to define a Python web API through static methods of classes,
-and allows auto-generation of corresponding javascript APIs to match.  The developer need not
-be concerned about the details of how to map routes nor to understand the details of HTTP transactions.
-Ths developer need only focus on development of a web API as a Python interface.
-
-Getting Started
----------------
-
-Let's look at setting up a simple WebApplication on your localhost:
-
->>> import asyncio
-... from bantam.http import web_api, RestMethod, WebApplication
-...
-... # noinspection PyNestedDecorators
-... class Greetings:
-...
-...     @web_api(content_type='text/html', method=RestMethod.GET)
-...     @staticmethod
-...     async def welcome(name: str) -> str:
-...         \"\"\"
-...         Welcome someone
-...
-...         :@param name: name of person to greet
-...         :return: a salutation of welcome
-...         \"\"\"
-...         return f"<html><body><p>Welcome, {name}!</p></body></html>"
-...
-...     @web_api(content_type='text/html', method=RestMethod.GET)
-...     @staticmethod
-...     async def goodbye(type_of_day: str) -> str:
-...         \"\"\"
-...         Tell someone goodbye by telling them to have a day (of the given type)
-...
-...         :@param type_of_day:  an adjective describe what type of day to have
-...         :return: a saltation of welcome
-...         \"\"\"
-...         return f"<html><body><p>Have a {type_of_day} day!</p></body></html>"
-...
-... if __name__ == '__main__':
-...     app = WebApplication()
-...     asyncio.get_event_loop().run_until_complete(app.start()) # default to localhost HTTP on port 8080
-
-Saving this to a file, 'saultations.py', you can run this start your server:
-
-.. code-block:: bash
-
-    % python3 salutations.py
-
-Then open a browser to the following URL's:
-
-* http://localhost:8080/Greetings/welcome?name=Bob
-* http://localhost:8080/Greetings/goodbye?type_of_day=wonderful
-
-to display various salutiations.
-
-To explain this code, the *@web_api* decorator declares a method that is mapped to a route. The route is determined
-by the class name, in this case *Greetings*, and the method name. Thus, the "welcome" method above, as a member of
-*Greetings* class, is mapped to the route '/Greetings/welcome".  There are some rules about methods declared
-as *@web_api*:
-
-#. They must be @staticmethod's.
-#. They must provide all type hints for parameters and return value,
-#. They must have parameters and return values of basic types (str, float, int bool) or a @dataclass class
-
-The query parameters provided in the full URL are mapped to the parameters in the Python method.  For example,
-the query parameter name=Box in the first uRL above maps to the *name* parameter of the *Greetings.welcome* method,
-with 'Bob' as the value.
-The query parameters are translated to the value and type expected by the
-Python API. If the value is not convertible to the proper type, an error code along with reason are returned.
-There are a few other options for parameters and return type that will be  discussed later on streaming.
-
-The methods can also be declared as POST operations.  In this case, parameter values would be sent as part of the
-payload of the request (not query parameters) as a simple JSON dictionary.
-
-.. caution::
-
-    Although the code prevents name collisions, the underlying (automated) routes do not, and a route must be unique.
-    Thus, each pair of class/method declared as a @web_api must be unique, including across differing modules.
-
+Main application definition (HTTP app)
 """
 import asyncio
 from asyncio import Task
@@ -148,11 +68,11 @@ def wrap(app, op):
 # noinspection PyUnresolvedReferences
 class WebApplication:
     """
-    Main class for running a WebApplication server. See the docs for *aiohttp* for information on the various
-    parameters.  Additional parameters are:
+    Main class for running a WebApplication server. See the documentation for *aiohttp* for information on the various
+    parameters.  Additional parameters for this class are:
 
-    :@param static_path: root path to where static files will be kept, mapped to a route "/static", if provided
-    :@param js_bundle_name: the name of the javascript file, **without** exetnesion, where the client-side API
+    :static_path: root path to where static files will be kept, mapped to a route "/static", if provided
+    :js_bundle_name: the name of the javascript file, **without** exetension, where the client-side API
        will be generated, if provided
     """
     _context: Dict[Awaitable, Request] = {}
@@ -368,9 +288,10 @@ class WebApplication:
         """
         start the app
 
-        :param modules: list of name of modules to import that contain the @web_api definitions to use
-        :param host: host of app, if TCP based
-        :param port: port to handle requests on (to listen on) if TCP based
+        :param modules: list of name of modules to import that contain the @web_api definitions to use, must not be
+           empty and will be imported to load the @web_api definitions
+        :param host: optional host of app, defaults to '127.0.0.1'
+        :param port: optional port to listen on (TCP)
         :param path: path, if using UNIX domain sockets to listen on (cannot specify both TCP and domain parameters)
         :param shutdown_timeout: force shutdown if a shutdown call fails to take hold after this many seconds
         :param ssl_context: for HTTPS server; if not provided, will default to HTTP connection
